@@ -624,5 +624,5 @@ main (gint argc,
 		test_recur_duration,
 		e_test_server_utils_teardown);
 
-	return e_test_server_utils_run ();
+	return e_test_server_utils_run (argc, argv);
 }
